[vlc-devel] [PATCH] Correct spelling: s/[sS]yncro/[sS]ynchro/

Zoran Turalija zoran.turalija at gmail.com
Tue Apr 9 11:27:09 CEST 2013


There is widespread use of words related to term synchronization
in VLC project. Also, common mistake is dropping letter H from
such words. This commit addresses this issue with exception of
not introducing letter H to word [sS]ync, thou [sS]ynch is also
correct, but really rarely used.
---
 extras/package/macosx/Resources/English.lproj/SyncTracks.xib |    2 +-
 modules/gui/macosx/TrackSynchronization.m                    |    2 +-
 modules/gui/qt4/components/extended_panels.cpp               |    2 +-
 modules/packetizer/dirac.c                                   |    8 ++++----
 po/vlc.pot                                                   |    2 +-
 share/lua/http/js/jquery.jstree.js                           |    2 +-
 6 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/extras/package/macosx/Resources/English.lproj/SyncTracks.xib b/extras/package/macosx/Resources/English.lproj/SyncTracks.xib
index 6c96fbe..b29ab57 100644
--- a/extras/package/macosx/Resources/English.lproj/SyncTracks.xib
+++ b/extras/package/macosx/Resources/English.lproj/SyncTracks.xib
@@ -276,7 +276,7 @@
                       <object class="NSTextFieldCell" key="NSCell" id="53850351">
                         <int key="NSCellFlags">68288064</int>
                         <int key="NSCellFlags2">272761856</int>
-                        <string key="NSContents">Subtitle track syncronization:</string>
+                        <string key="NSContents">Subtitle track synchronization:</string>
                         <reference key="NSSupport" ref="26"/>
                         <reference key="NSControlView" ref="662764430"/>
                         <reference key="NSBackgroundColor" ref="592262308"/>
diff --git a/modules/gui/macosx/TrackSynchronization.m b/modules/gui/macosx/TrackSynchronization.m
index 1206dba..c0b8f3c 100644
--- a/modules/gui/macosx/TrackSynchronization.m
+++ b/modules/gui/macosx/TrackSynchronization.m
@@ -63,7 +63,7 @@ static VLCTrackSynchronization *_o_sharedInstance = nil;
     [[o_av_value_fld formatter] setFormat:[NSString stringWithFormat:@"#,##0.000 %@", _NS("s")]];
     [o_av_value_fld setToolTip: _NS("A positive value means that the audio is ahead of the video")];
     [o_sv_lbl setStringValue: _NS("Subtitles/Video")];
-    [o_sv_advance_lbl setStringValue: _NS("Subtitle track syncronization:")];
+    [o_sv_advance_lbl setStringValue: _NS("Subtitle track synchronization:")];
     [[o_sv_advance_value_fld formatter] setFormat:[NSString stringWithFormat:@"#,##0.000 %@", _NS("s")]];
     [o_sv_advance_value_fld setToolTip: _NS("A positive value means that the subtitles are ahead of the video")];
     [o_sv_speed_lbl setStringValue: _NS("Subtitle speed:")];
diff --git a/modules/gui/qt4/components/extended_panels.cpp b/modules/gui/qt4/components/extended_panels.cpp
index 29f6ff7..7c87b9c 100644
--- a/modules/gui/qt4/components/extended_panels.cpp
+++ b/modules/gui/qt4/components/extended_panels.cpp
@@ -1476,7 +1476,7 @@ SyncControls::SyncControls( intf_thread_t *_p_intf, QWidget *_parent ) :
     QGridLayout *subsLayout = new QGridLayout( subsBox );
 
     QLabel *subsLabel = new QLabel;
-    subsLabel->setText( qtr( "Subtitle track syncronization:" ) );
+    subsLabel->setText( qtr( "Subtitle track synchronization:" ) );
     subsLayout->addWidget( subsLabel, 0, 0, 1, 1 );
 
     subsSpin = new SyncWidget( this );
diff --git a/po/vlc.pot b/po/vlc.pot
index e5e7f05..df3c5db 100644
--- a/po/vlc.pot
+++ b/po/vlc.pot
@@ -17373,7 +17373,7 @@ msgid "Audio track synchronization:"
 msgstr ""
 
 #: modules/gui/qt4/components/extended_panels.cpp:1545
-msgid "Subtitle track syncronization:"
+msgid "Subtitle track synchronization:"
 msgstr ""
 
 #: modules/gui/qt4/components/extended_panels.cpp:1552
diff --git a/share/lua/http/js/jquery.jstree.js b/share/lua/http/js/jquery.jstree.js
index 3ae1b77..59e4929 100644
--- a/share/lua/http/js/jquery.jstree.js
+++ b/share/lua/http/js/jquery.jstree.js
@@ -507,7 +507,7 @@
 					});
 				}
 				if(done) { 
-					// TODO: find a more elegant approach to syncronizing returning requests
+					// TODO: find a more elegant approach to synchronizing returning requests
 					if(this.data.core.reopen) { clearTimeout(this.data.core.reopen); }
 					this.data.core.reopen = setTimeout(function () { _this.__callback({}, _this); }, 50);
 					this.data.core.refreshing = false;
diff --git a/modules/packetizer/dirac.c b/modules/packetizer/dirac.c
index 04ec28a..65121cb 100644
--- a/modules/packetizer/dirac.c
+++ b/modules/packetizer/dirac.c
@@ -735,7 +735,7 @@ static block_t *dirac_DoSync( decoder_t *p_dec )
             {
                 return NULL; /* retry later */
             }
-            /* attempt to syncronise backwards from pu.u_next_offset */
+            /* attempt to synchronise backwards from pu.u_next_offset */
             p_sys->i_offset = pu.u_next_offset;
             /* fall through */
         case TRY_SYNC: /* -> SYNCED | NOT_SYNCED */
@@ -851,7 +851,7 @@ static int dirac_InspectDataUnit( decoder_t *p_dec, block_t **pp_block, block_t
         Actually, this is a bad idea:
          - It sets the discontinuity for every dirac EOS packet
            which doesnt imply a time discontinuity.
-         - When the syncronizer detects a real discontinuity, it
+         - When the synchronizer detects a real discontinuity, it
            should copy the flags through.
         p_eu->i_flags |= BLOCK_FLAG_DISCONTINUITY;
         */
@@ -1227,7 +1227,7 @@ static block_t *Packetize( decoder_t *p_dec, block_t **pp_block )
             if( p_block )
             {
                 p_block->p_next = dirac_EmitEOS( p_dec, 13 );
-                /* need two EOS to ensure it gets detected by syncro
+                /* need two EOS to ensure it gets detected by synchro
                  * duplicates get discarded in forming encapsulation unit */
             }
         }
@@ -1245,7 +1245,7 @@ static block_t *Packetize( decoder_t *p_dec, block_t **pp_block )
     }
 
     /* form as many encapsulation units as possible, give up
      * when the syncronizer runs out of input data */
     while( ( p_block = dirac_DoSync( p_dec ) ) )
     {
         p_block = dirac_BuildEncapsulationUnit( p_dec, p_block );
@@ -1245,7 +1245,7 @@ static block_t *Packetize( decoder_t *p_dec, block_t **pp_block )
 
     /* form as many encapsulation units as possible, give up
-     * when the syncronizer runs out of input data */
+     * when the synchronizer runs out of input data */
     while( ( p_block = dirac_DoSync( p_dec ) ) )
     {
-- 
1.7.10.4


-- 
Kind regards,
Zoran Turalija



More information about the vlc-devel mailing list